MarginPairwiseLoss
==================

.. currentmodule:: pykeen.losses

.. autoclass:: MarginPairwiseLoss
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~MarginPairwiseLoss.forward
      ~MarginPairwiseLoss.process_lcwa_scores
      ~MarginPairwiseLoss.process_slcwa_scores

   .. rubric:: Methods Documentation

   .. automethod:: forward
   .. automethod:: process_lcwa_scores
   .. automethod:: process_slcwa_scores
